aboutsummaryrefslogtreecommitdiffstats
path: root/src/imports/controls/qquicktheme.cpp
diff options
context:
space:
mode:
authorJ-P Nurmi <jpnurmi@theqtcompany.com>2015-09-30 17:47:36 +0200
committerJ-P Nurmi <jpnurmi@theqtcompany.com>2015-10-01 09:03:42 +0000
commit3f2ac678971694fe6144a4e15197aff2ca38639b (patch)
tree06440cbf63932fb008f3aab29835b07d0310bada /src/imports/controls/qquicktheme.cpp
parentb948c83255239a6fe49fca58a98f90e796ce9047 (diff)
Rename QtQuick.Controls 2.0 to Qt.labs.controls 1.0
Change-Id: I142622dd85e95ef70b11132e77ccf48701f2cabc Reviewed-by: Mitch Curtis <mitch.curtis@theqtcompany.com>
Diffstat (limited to 'src/imports/controls/qquicktheme.cpp')
-rw-r--r--src/imports/controls/qquicktheme.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/imports/controls/qquicktheme.cpp b/src/imports/controls/qquicktheme.cpp
index 3cfbc689..395d60d7 100644
--- a/src/imports/controls/qquicktheme.cpp
+++ b/src/imports/controls/qquicktheme.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
@@ -51,7 +51,7 @@ QT_BEGIN_NAMESPACE
\qmltype Theme
\inherits QtObject
\instantiates QQuickThemeAttached
- \inqmlmodule QtQuick.Controls
+ \inqmlmodule Qt.labs.controls
\ingroup utilities
\brief A theme interface.
@@ -59,46 +59,46 @@ QT_BEGIN_NAMESPACE
*/
/*!
- \qmlattachedproperty color QtQuick.Controls::Theme::accentColor
+ \qmlattachedproperty color Qt.labs.controls::Theme::accentColor
*/
/*!
- \qmlattachedproperty color QtQuick.Controls::Theme::backgroundColor
+ \qmlattachedproperty color Qt.labs.controls::Theme::backgroundColor
*/
/*!
- \qmlattachedproperty color QtQuick.Controls::Theme::disabledColor
+ \qmlattachedproperty color Qt.labs.controls::Theme::disabledColor
*/
/*!
- \qmlattachedproperty color QtQuick.Controls::Theme::focusColor
+ \qmlattachedproperty color Qt.labs.controls::Theme::focusColor
*/
/*!
- \qmlattachedproperty color QtQuick.Controls::Theme::frameColor
+ \qmlattachedproperty color Qt.labs.controls::Theme::frameColor
*/
/*!
- \qmlattachedproperty color QtQuick.Controls::Theme::pressColor
+ \qmlattachedproperty color Qt.labs.controls::Theme::pressColor
*/
/*!
- \qmlattachedproperty color QtQuick.Controls::Theme::selectedTextColor
+ \qmlattachedproperty color Qt.labs.controls::Theme::selectedTextColor
*/
/*!
- \qmlattachedproperty color QtQuick.Controls::Theme::selectionColor
+ \qmlattachedproperty color Qt.labs.controls::Theme::selectionColor
*/
/*!
- \qmlattachedproperty color QtQuick.Controls::Theme::shadowColor
+ \qmlattachedproperty color Qt.labs.controls::Theme::shadowColor
*/
/*!
- \qmlattachedproperty color QtQuick.Controls::Theme::textColor
+ \qmlattachedproperty color Qt.labs.controls::Theme::textColor
*/
-Q_GLOBAL_STATIC_WITH_ARGS(QQuickThemeData, globalThemeData, (QString::fromLatin1(":/qtquickcontrols/theme.json")))
+Q_GLOBAL_STATIC_WITH_ARGS(QQuickThemeData, globalThemeData, (QString::fromLatin1(":/qtlabscontrols/theme.json")))
static QQuickThemeAttached *themeInstance(QQmlEngine *engine)
{
@@ -3,7 +3,7 @@
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Controls module of the Qt Toolkit.
+** This file is part of the Qt Labs Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$